Crate hyperlight_guest_macro

Crate hyperlight_guest_macro 

Attribute Macros

guest_function
Attribute macro to mark a function as a guest function. This will register the function so that it can be called by the host.
host_function
Attribute macro to mark a function as a host function. This will generate a function that calls the host function with the same name.