Crate hyperlight_guest_macro

Crate hyperlight_guest_macro 

Attribute Macros

dispatch
Attribute macro to mark a function as the dispatch function for the guest. This is the function that will be called by the host when a function call is made to a function that is not registered with the host.
guest_function
Attribute macro to mark a function as a guest function. This will register the function so that it can be called by the host.
host_function
Attribute macro to mark a function as a host function. This will generate a function that calls the host function with the same name.
main
Attribute macro to mark a function as the main entry point for the guest. This will generate a function that is called by the host at program initialization.