Attribute macro to mark a function as the dispatch function for the guest.
This is the function that will be called by the host when a function call is made
to a function that is not registered with the host.
Attribute macro to mark a function as the main entry point for the guest.
This will generate a function that is called by the host at program initialization.